@@ -7,7 +7,8 @@ from project_archer.environment.read_shell_parameters import (
 
 
 def edit_project(args, env):
-    folder = project_folder(args)
+    # the project name already contains the zone information
+    folder = project_folder(args, custom_zone="")
 
     # if there is an argument on the shell, use that,
     # otherwise use "current project"
@@ -18,8 +19,4 @@ def edit_project(args, env):
         if not target_project:
             target_project = "undefined"
 
-    # if the target_project is in a zone, it's prefixed by the zone name.
-    # if that's the case, we need to drop the zone information.
-    env.execute(
-        "$EDITOR " + os.path.join(folder, os.path.basename(target_project + ".yml"))
-    )
+    env.execute("$EDITOR " + os.path.join(folder, target_project + ".yml"))
