@@ -1,6 +1,7 @@
 import os
+from typing import Optional
 
-from termcolor_util import cyan, red
+from termcolor_util import blue, yellow
 
 from project_archer.environment.read_shell_parameters import (
     project_folder,
@@ -9,12 +10,12 @@ from project_archer.environment.read_shell_parameters import (
 from project_archer.storage.project_data import read_project_yml
 
 
-def list_projects(args, env):
-    folder = project_folder(args)
-    zone = current_zone(args.internalRunMode)
+def list_projects(args, env, *, custom_zone: Optional[str] = None):
+    folder = project_folder(args, custom_zone=custom_zone)
+    zone = current_zone(args.internalRunMode) if custom_zone is None else custom_zone
 
     if zone:
-        env.log(red("= " + zone, bold=True))
+        env.log(yellow("= " + zone, bold=True))
 
     items = list(sorted(os.listdir(folder)))
 
@@ -26,7 +27,7 @@ def list_projects(args, env):
     if available_zones:
         env.log("Available zones:")
         for available_zone in available_zones:
-            env.log("- " + red(available_zone))
+            env.log("- " + yellow(available_zone))
 
     env.log("Available projects:")
     for filename in items:
@@ -37,7 +38,7 @@ def list_projects(args, env):
         project_data = read_project_yml(file_data)
         env.log(
             "- "
-            + cyan(os.path.splitext(filename)[0], bold=True)
+            + blue(os.path.splitext(filename)[0], bold=True)
             + ": "
             + project_data["name"]
         )
