@@ -1,5 +1,7 @@
-from typing import Optional
 import os
+from typing import Optional
+
+from termcolor_util import green, blue, yellow, red
 
 from project_archer.environment.read_shell_parameters import (
     archer_home,
@@ -13,7 +15,7 @@ from project_archer.storage.project_data import read_project_yml
 def select_project(args, env):
     zone = current_zone(args.internalRunMode)
 
-    if zone:
+    if zone and "/" not in args.project:
         project_name = os.path.join(zone, args.project)
     else:
         project_name = args.project
@@ -21,32 +23,47 @@ def select_project(args, env):
     if is_no_project_file(project_name, args.internalRunMode) and is_zone_folder(
         project_name, args.internalRunMode
     ):
-        select_zone_str(
-            internal_run_mode=args.internalRunMode, zone=project_name, env=env
-        )
+        select_zone_str(args=args, env=env, zone=project_name)
+
         return
 
+    if "/" in args.project:
+        select_zone_str(args=args, env=env, zone="/".join(args.project.split("/")[:-1]))
+
     project_data = read_project_data(project_name, args.internalRunMode)
+    env.log(
+        "Loading " + args.internalRunMode + ": " + blue(project_data["name"], bold=True)
+    )
 
     # 1. check if the project can be activated
     required_envvars = project_data["requires"]
-    missing_envvars = [
-        v
-        for v in required_envvars
-        if not os.getenv(v) and v not in project_data["exports"]
-    ]
+    missing_envvars = set(
+        [
+            v
+            for v in required_envvars
+            if not os.getenv(v) and v not in project_data["exports"]
+        ]
+    )
 
     if len(missing_envvars):
-        env.log("Unable to activate: " + project_name + "!")
+        env.log(red("Unable to activate: ") + red(project_name, bold=True) + red("!"))
         env.log(
-            "Missing environment variables: '" + "', '".join(missing_envvars) + "'."
+            red(
+                "Missing environment variables: '" + "', '".join(missing_envvars) + "'."
+            )
         )
         return  # bailing out
 
     old_project_name = current_project(args.internalRunMode)
     if old_project_name == project_name:
         env.log(
-            "The current " + args.internalRunMode + " is already: " + project_name + "."
+            yellow(
+                "The current "
+                + args.internalRunMode
+                + " is already: "
+                + project_name
+                + "."
+            )
         )
         return  # bailing out
 
@@ -58,6 +75,10 @@ def select_project(args, env):
         unset_envvars(old_project["exports"], env)
 
     # 3. export the environment variables
+    env.set_envvar(
+        "CIPLOGIC_ARCHER_CURRENT_" + args.internalRunMode.upper(), project_name
+    )
+
     for export_name in project_data["exports"]:
         env.set_envvar(export_name, project_data["exports"][export_name])
 
@@ -67,10 +88,11 @@ def select_project(args, env):
     # 5. export the commands
     export_commands(project_data["commands"], env)
 
-    # print(project_data['name'], project_name)
-    env.log("Activated " + args.internalRunMode + ": " + project_data["name"])
-    env.set_envvar(
-        "CIPLOGIC_ARCHER_CURRENT_" + args.internalRunMode.upper(), project_name
+    env.log(
+        "Activated "
+        + args.internalRunMode
+        + ": "
+        + blue(project_data["name"], bold=True)
     )
 
 
@@ -162,10 +184,10 @@ def execute_commands(commands, env):
 
 
 def export_commands(commands, env):
-    env.log("Commands: ")
+    env.log(yellow("Commands:", bold=True))
 
     for command in commands:
-        env.log("   " + command)
+        env.log("- " + green(command))
         env.define_command(command, commands[command])
 
 
